@@ -1058,7 +1058,9 @@ class CameraEvent(NestBase):
     @property
     def end_time(self):
         if 'end_time' in self._event:
-            return parse_time(self._event['end_time'])
+            end_time = parse_time(self._event['end_time'])
+            if end_time:
+                return end_time + datetime.timedelta(seconds=30)
 
     @property
     def urls_expire_time(self):
